@@ -15,23 +15,25 @@ from .constant import (
     BLANK_IMAGE,
     DEVICES_PATH,
     FAST_REFRESH_INTERVAL,
-    INITIAL_REFRESH_DELAY,
-    MEDIA_LIBRARY_DELAY,
-    MODEL_ESSENTIAL,
+    MODEL_ESSENTIAL_SPOTLIGHT,
+    MODEL_ESSENTIAL_XL_SPOTLIGHT,
     MODEL_ESSENTIAL_INDOOR,
+    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
     MODEL_PRO_3_FLOODLIGHT,
     MODEL_PRO_4,
     MODEL_PRO_5,
     MODEL_WIRED_VIDEO_DOORBELL,
-    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
     MODEL_ESSENTIAL_VIDEO_DOORBELL,
     MODEL_GO,
     MODEL_GO_2,
-    MODEL_ESSENTIAL_XL,
+    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
     PING_CAPABILITY,
-    REFRESH_CAMERA_DELAY,
-    RESOURCE_CAPABILITY,
     SLOW_REFRESH_INTERVAL,
     TOTAL_BELLS_KEY,
     TOTAL_CAMERAS_KEY,
@@ -50,7 +52,7 @@ from .util import time_to_arlotime
 
 _LOGGER = logging.getLogger("pyaarlo")
 
-__version__ = "0.8.0.3"
+__version__ = "0.8.0.11"
 
 
 class PyArlo(object):
@@ -177,11 +179,7 @@ class PyArlo(object):
         self._be = ArloBackEnd(self)
         self._ml = ArloMediaLibrary(self)
 
-        # Failed to login, then stop now!
-        if not self._be.is_connected:
-            return
-
-        self._lock = threading.Condition()
+        # Make sure they are empty.
         self._locations = []
         self._bases = []
         self._cameras = []
@@ -189,6 +187,12 @@ class PyArlo(object):
         self._doorbells = []
         self._sensors = []
 
+        # Failed to login, then stop now!
+        if not self._be.is_connected:
+            return
+
+        self._lock = threading.Condition()
+
         # On day flip we do extra work, record today.
         self._today = datetime.date.today()
 
@@ -237,11 +241,17 @@ class PyArlo(object):
                     MODEL_PRO_3_FLOODLIGHT,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
-                    MODEL_ESSENTIAL,
+                    MODEL_ESSENTIAL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_SPOTLIGHT,
                     MODEL_ESSENTIAL_INDOOR,
-                    MODEL_ESSENTIAL_XL,
-                    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-                    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
                     MODEL_ESSENTIAL_VIDEO_DOORBELL,
                     MODEL_GO_2
             )):
@@ -254,11 +264,11 @@ class PyArlo(object):
                 or dtype == "arloq"
                 or dtype == "arloqs"
                 or device.get("modelId").startswith((
-                        MODEL_GO,
-                        MODEL_WIRED_VIDEO_DOORBELL,
-                        MODEL_WIRED_VIDEO_DOORBELL2_HD,
-                        MODEL_WIRED_VIDEO_DOORBELL2_2K,
-                        MODEL_ESSENTIAL_VIDEO_DOORBELL
+                    MODEL_GO,
+                    MODEL_WIRED_VIDEO_DOORBELL,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
+                    MODEL_ESSENTIAL_VIDEO_DOORBELL
                 ))
             ):
                 self._cameras.append(ArloCamera(dname, self, device))
