@@ -41,9 +41,15 @@ from .constant import (
     MEDIA_UPLOAD_KEYS,
     MIRROR_KEY,
     MODEL_BABY,
-    MODEL_ESSENTIAL,
+    MODEL_ESSENTIAL_SPOTLIGHT,
+    MODEL_ESSENTIAL_XL_SPOTLIGHT,
     MODEL_ESSENTIAL_INDOOR,
-    MODEL_ESSENTIAL_XL,
+    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
+    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
     MODEL_PRO_2,
     MODEL_PRO_3,
     MODEL_PRO_3_FLOODLIGHT,
@@ -51,8 +57,8 @@ from .constant import (
     MODEL_PRO_5,
     MODEL_ULTRA,
     MODEL_WIRED_VIDEO_DOORBELL,
-    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
     MODEL_ESSENTIAL_VIDEO_DOORBELL,
     MODEL_GO,
     MOTION_DETECTED_KEY,
@@ -1360,7 +1366,11 @@ class ArloCamera(ArloChildDevice):
 
     def has_capability(self, cap):
         if cap in (BATTERY_KEY,):
-            if self.model_id.startswith(MODEL_ESSENTIAL_INDOOR):
+            if self.model_id.startswith((
+                    MODEL_ESSENTIAL_INDOOR,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
+            )):
                 return False
             else:
                 return True
@@ -1370,9 +1380,15 @@ class ArloCamera(ArloChildDevice):
             return True
         if cap in (AUDIO_DETECTED_KEY,):
             if self.model_id.startswith((
-                    MODEL_ESSENTIAL,
+                    MODEL_ESSENTIAL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_SPOTLIGHT,
                     MODEL_ESSENTIAL_INDOOR,
-                    MODEL_ESSENTIAL_XL,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
                     MODEL_PRO_2,
                     MODEL_PRO_3,
                     MODEL_PRO_3_FLOODLIGHT,
@@ -1387,23 +1403,33 @@ class ArloCamera(ArloChildDevice):
                 return True
         if cap in (SIREN_STATE_KEY,):
             if self.model_id.startswith((
-                    MODEL_ESSENTIAL,
+                    MODEL_ESSENTIAL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_SPOTLIGHT,
                     MODEL_ESSENTIAL_INDOOR,
-                    MODEL_ESSENTIAL_XL,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
                     MODEL_PRO_3,
                     MODEL_PRO_3_FLOODLIGHT,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
                     MODEL_ULTRA,
-                    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-                    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
                     MODEL_ESSENTIAL_VIDEO_DOORBELL,
             )):
                 return True
         if cap in (SPOTLIGHT_KEY,):
             if self.model_id.startswith((
-                    MODEL_ESSENTIAL,
-                    MODEL_ESSENTIAL_XL,
+                    MODEL_ESSENTIAL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
                     MODEL_PRO_3,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
@@ -1426,13 +1452,19 @@ class ArloCamera(ArloChildDevice):
                     MODEL_PRO_3_FLOODLIGHT,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
-                    MODEL_ESSENTIAL,
-                    MODEL_ESSENTIAL_XL,
+                    MODEL_ESSENTIAL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_SPOTLIGHT,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_XL_OUTDOOR_GEN2_HD,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_OUTDOOR_GEN2_HD,
                     MODEL_WIRED_VIDEO_DOORBELL,
-                    MODEL_WIRED_VIDEO_DOORBELL2_HD,
-                    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL_GEN2_2K,
                     MODEL_ESSENTIAL_VIDEO_DOORBELL,
                     MODEL_ESSENTIAL_INDOOR,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_2K,
+                    MODEL_ESSENTIAL_INDOOR_GEN2_HD,
                     MODEL_GO,
             )):
                 return False
